Flags

Struct Flags 

pub struct Flags { /* private fields */ }
Available on crate feature archive only.
Abstracted flag access and manipulation struct. Basically just a tiny, bitflags

Implementations

Source

impl Flags

pub const RESERVED_MASK: u32 = 4_294_901_760u32

Bits reserved for internal use.

pub const BYTES: usize = 4usize

The size in bytes of any flags entry

pub const COMPRESSED_FLAG: u32 = 2_147_483_648u32

This flag shows that the adjacent entry is compressed

pub const LZ4_COMPRESSED: u32 = 1_073_741_824u32

This entry was compressed using the LZ4 scheme for very fast decompression with average compression ratios

pub const SNAPPY_COMPRESSED: u32 = 536_870_912u32

This entry was compressed using the snappy scheme for balanced compression properties

pub const BROTLI_COMPRESSED: u32 = 268_435_456u32

This entry was compressed using the brotli scheme for higher compression ratios but slower compression speed

pub const SIGNED_FLAG: u32 = 134_217_728u32

The flag that denotes that the archive source has signatures

pub const ENCRYPTED_FLAG: u32 = 33_554_432u32

The flag that shows data in the leaf in encrypted

pub const fn from_bits(bits: u32) -> Self

Construct a Flags struct from a u32 number

pub const fn bits(&self) -> u32

Returns a copy of the underlying number.

pub const fn new() -> Self

Create a new empty instance

pub const fn set(&mut self, bit: u32, toggle: bool) -> InternalResult<u32>

Set a bit into the underlying u32, will fail if set into the reserved mask. The toggle parameter specifies whether to insert the flags (when true), or to pop the flag, (when false).

pub const fn contains(&self, bit: u32) -> bool

Checks whether the given flag is set.