Module vach::builder[][src]

Builder related data structures and logic

Structs

The archive builder. Provides an interface with which one can configure and build out valid vach archives.

Allows for the customization of valid vach archives during their construction. Such as custom MAGIC, custom Header flags and signing by providing a keypair.

A wrapper around an io::Read handle. Allows for multiple types of data implementing io::Read to be used under one structure. Also used to configure how data will be processed and embedded into an write target.

Enums

Configures how Leafs should be compressed. Default is CompressMode::Never.

All errors manifestable within vach collected into a neat enum

Type Definitions

Internal Result type alias used by vach. Basically equal to: Result<T, InternalError>