pub enum CompressMode {
Never,
Always,
Detect,
}Available on crate features
builder and compression only.Expand description
Configures how a Leaf should be compressed.
Variants
Never
The data is never compressed and is embedded as is.
Always
The data will always be compressed
Detect
The compressed data is used, only if it is smaller than the original data.