CompressionAlgorithm

Enum CompressionAlgorithm 

pub enum CompressionAlgorithm {
    Snappy,
    LZ4,
    Brotli(u32),
}
Available on crate features builder and compression only.
Allows the user to specify which of three Compression Algorithms to use.

Variants



Snappy

Uses snappy for a well balanced compression experienced



LZ4

Uses LZ4 for very fast decompression with average compression ratios



Brotli(u32)

Uses brotli for higher compression ratios but much slower compression speed Allows one to specify the quality of the compression, from 1-11. (9 Recommended, 11 for extra compression)