Leaf

Struct Leaf 

pub struct Leaf<R = &'static [u8]> {
    pub handle: R,
    pub id: Arc<str>,
    pub content_version: u8,
    pub flags: Flags,
    pub compress: CompressMode,
    pub compression_algo: CompressionAlgorithm,
    pub encrypt: bool,
    pub sign: bool,
}
Available on crate feature builder only.
A named (ID) wrapper around an io::Read handle, tagged with extra metadata.

Fields

handle: R

source data

id: Arc<str>

The ID under which the embedded data will be referenced

content_version: u8

The version of the content, allowing you to track obsolete data.

flags: Flags

The flags that will go into the archive write target.

compress: CompressMode
Available on crate feature compression only.

How a Leaf should be compressed

compression_algo: CompressionAlgorithm
Available on crate feature compression only.

The specific compression algorithm to use

encrypt: bool
Available on crate feature crypto only.

Use encryption when writing into the target.

sign: bool
Available on crate feature crypto only.

Whether to include a signature with this Leaf

Implementations

Source

impl<R: Read + Send + Sync> Leaf<R>

pub fn new<S: AsRef<str>>(handle: R, id: S) -> Leaf<R>

Creates a new Leaf wrapping around the given Read handle, with an ID

pub fn template<R2>(self, other: &Leaf<R2>) -> Self

Copy all fields from another Leaf, except for handle and id.

pub fn compress(self, compress: CompressMode) -> Self

Available on crate feature compression only.

Setter for the compress field

pub fn version(self, content_version: u8) -> Self

Setter for the content_version field

pub fn flags(self, flags: Flags) -> Self

Setter for the flags field

pub fn encrypt(self, encrypt: bool) -> Self

Available on crate feature crypto only.

Setter for the encrypt field

pub fn sign(self, sign: bool) -> Self

Available on crate feature crypto only.

Setter for the sign field

pub fn compression_algo(self, compression_algo: CompressionAlgorithm) -> Self

Available on crate feature compression only.

Setter for the compression_algo field