pub struct Flags { /* private fields */ }Available on crate feature
archive only.Expand description
Abstracted flag access and manipulation struct.
Basically just a tiny, bitflags
Implementations
Sourceimpl Flags
impl Flags
Sourcepub const RESERVED_MASK: u32 = 4_294_901_760u32
pub const RESERVED_MASK: u32 = 4_294_901_760u32
Bits reserved for internal use.
Sourcepub const COMPRESSED_FLAG: u32 = 2_147_483_648u32
pub const COMPRESSED_FLAG: u32 = 2_147_483_648u32
This flag shows that the adjacent entry is compressed
Sourcepub const LZ4_COMPRESSED: u32 = 1_073_741_824u32
pub const LZ4_COMPRESSED: u32 = 1_073_741_824u32
This entry was compressed using the LZ4 scheme for very fast decompression with average compression ratios
Sourcepub const SNAPPY_COMPRESSED: u32 = 536_870_912u32
pub const SNAPPY_COMPRESSED: u32 = 536_870_912u32
This entry was compressed using the snappy scheme for balanced compression properties
Sourcepub const BROTLI_COMPRESSED: u32 = 268_435_456u32
pub const BROTLI_COMPRESSED: u32 = 268_435_456u32
This entry was compressed using the brotli scheme for higher compression ratios but slower compression speed
Sourcepub const SIGNED_FLAG: u32 = 134_217_728u32
pub const SIGNED_FLAG: u32 = 134_217_728u32
The flag that denotes that the archive source has signatures
Sourcepub const ENCRYPTED_FLAG: u32 = 33_554_432u32
pub const ENCRYPTED_FLAG: u32 = 33_554_432u32
The flag that shows data in the leaf in encrypted